( cd usr/lib/debug ; rm -rf libnss_nis.so.2 )
( cd usr/lib/debug ; ln -sf libnss_nis-2.3.1.so libnss_nis.so.2 )
( cd usr/lib/debug ; rm -rf libm.so.6 )
( cd usr/lib/debug ; ln -sf libm-2.3.1.so libm.so.6 )
( cd usr/lib/debug ; rm -rf libnss_files.so.2 )
( cd usr/lib/debug ; ln -sf libnss_files-2.3.1.so libnss_files.so.2 )
( cd usr/lib/debug ; rm -rf libresolv.so.2 )
( cd usr/lib/debug ; ln -sf libresolv-2.3.1.so libresolv.so.2 )
( cd usr/lib/debug ; rm -rf libnsl.so.1 )
( cd usr/lib/debug ; ln -sf libnsl-2.3.1.so libnsl.so.1 )
( cd usr/lib/debug ; rm -rf libutil.so.1 )
( cd usr/lib/debug ; ln -sf libutil-2.3.1.so libutil.so.1 )
( cd usr/lib/debug ; rm -rf libnss_compat.so.2 )
( cd usr/lib/debug ; ln -sf libnss_compat-2.3.1.so libnss_compat.so.2 )
( cd usr/lib/debug ; rm -rf libthread_db.so.1 )
( cd usr/lib/debug ; ln -sf libthread_db-1.0.so libthread_db.so.1 )
( cd usr/lib/debug ; rm -rf libnss_hesiod.so.2 )
( cd usr/lib/debug ; ln -sf libnss_hesiod-2.3.1.so libnss_hesiod.so.2 )
( cd usr/lib/debug ; rm -rf libanl.so.1 )
( cd usr/lib/debug ; ln -sf libanl-2.3.1.so libanl.so.1 )
( cd usr/lib/debug ; rm -rf libcrypt.so.1 )
( cd usr/lib/debug ; ln -sf libcrypt-2.3.1.so libcrypt.so.1 )
( cd usr/lib/debug ; rm -rf libBrokenLocale.so.1 )
( cd usr/lib/debug ; ln -sf libBrokenLocale-2.3.1.so libBrokenLocale.so.1 )
( cd usr/lib/debug ; rm -rf libdl.so.2 )
( cd usr/lib/debug ; ln -sf libdl-2.3.1.so libdl.so.2 )
( cd usr/lib/debug ; rm -rf libnss_dns.so.2 )
( cd usr/lib/debug ; ln -sf libnss_dns-2.3.1.so libnss_dns.so.2 )
( cd usr/lib/debug ; rm -rf libpthread.so.0 )
( cd usr/lib/debug ; ln -sf libpthread-0.10.so libpthread.so.0 )
( cd usr/lib/debug ; rm -rf libnss_nisplus.so.2 )
( cd usr/lib/debug ; ln -sf libnss_nisplus-2.3.1.so libnss_nisplus.so.2 )
( cd usr/lib/debug ; rm -rf libc.so.6 )
( cd usr/lib/debug ; ln -sf libc-2.3.1.so libc.so.6 )
( cd usr/lib/debug ; rm -rf librt.so.1 )
( cd usr/lib/debug ; ln -sf librt-2.3.1.so librt.so.1 )
